from machine import Pin, Timer

# Define LEDs
led1 = Pin(0, Pin.OUT)
led2 = Pin(1, Pin.OUT)
led3 = Pin(26, Pin.OUT)
leds = [led1, led2, led3]  # List of LEDs for easy access

# Initialize variables
current_led = 0  # Index for the current LED in sequence
sequence_started = False  # Flag to indicate whether sequence has started

# Timer for LED sequence
timer = Timer()

#Start all the LEDS as off
led1.value(0)
led2.value(0)
led3.value(0)

def blink(timer):
    global current_led
    if sequence_started:  # Only run sequence if started
        for led in leds:
            led.value(0)  # Turn off all LEDs
        leds[current_led].value(1)  # Turn on the current LED
        current_led = (current_led + 1) % len(leds)  # Move to the next LED

def start_sequence(pin):
    global sequence_started
    # Toggle the sequence start/stop
    sequence_started = not sequence_started
    if sequence_started:
        timer.init(freq=2.5, mode=Timer.PERIODIC, callback=blink)  # Start timer for LED sequence
    else:
        timer.deinit()  # Stop the timer and thereby the sequence
        for led in leds:  # Turn off all LEDs when sequence is stopped
            led.value(0)

# Define button with internal pull-up resistor
button = Pin(27, Pin.IN, Pin.PULL_UP)

# Interrupt for button press
button.irq(trigger=Pin.IRQ_FALLING, handler=start_sequence)
